.. Pacifica Notifications documentation master file, created by
   sphinx-quickstart on Thu Dec  6 20:05:08 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Pacifica Notifications' documentation!
==================================================

This service is a `Pacifica Policy <https://github.com/pacifica/pacifica-policy.git>`_
based routing mechanism for data subscribers to execute workflows based on the
availability of data in Pacifica.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   configuration
   exampleusage
   consumer-expectations
   notify

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
